# -*- coding: utf-8 -*-
"""
Django Status application.
"""
__version__ = '1.0.2'
__license__ = 'GPLv3'

__author__ = 'José Antonio Perdiguero López'
__email__ = 'perdy.hh@gmail.com'

__url__ = 'https://github.com/PeRDy/django-status'
__description__ = 'Application that provides an API to check the status of some parts and some utilities like ping.'

default_app_config = 'status.apps.Status'
